@@ -43,8 +43,8 @@ factory.register(
     extractors=[generic_extractor, autocomplete_extractor], 
     edit_renderers=[input_generic_renderer, autocomplete_renderer])
 
-factory.doc['widget']['autocomplete'] = \
-"""Add-on widget `yafowil.widget.autocomplete 
+factory.doc['blueprint']['autocomplete'] = \
+"""Add-on blueprint `yafowil.widget.autocomplete 
 <http://github.com/bluedynamics/yafowil.widget.autocomplete/>`_ utilizing 
 ``jquery.ui.autocomplete`` to offer the user a selection based on the input 
 given so far.
